@@ -2,15 +2,10 @@ use regex::Regex;
 
 use super::*;
 
-pub(crate) fn lint(commit_message: &str) -> Result<(), LintingError> {
+pub(super) fn lint(commit_message: &str) -> Result<(), LintingError> {
     lazy_static! {
         static ref ANGULAR_TYPE_REGEX: Regex = Regex::new(&format!(
-            r"(?i)^{}{}{}{}{}:",
-            *OPTIONAL_PRECEDING_WHITESPACE,
-            ANGULAR_TYPE,
-            OPTIONAL_EXCLAMATION,
-            OPTIONAL_EMPTY_SCOPE_OR_SCOPE,
-            OPTIONAL_EXCLAMATION,
+            r"(?i)^{OPTIONAL_PRECEDING_WHITESPACE}{ANGULAR_TYPE}{OPTIONAL_EXCLAMATION}{OPTIONAL_EMPTY_SCOPE_OR_SCOPE}{OPTIONAL_EXCLAMATION}:",
         ))
         .unwrap();
     }
