@@ -3,12 +3,7 @@ use super::*;
 pub(crate) fn lint(commit_message: &str) -> Result<(), LintingError> {
     lazy_static! {
         static ref EMPTY_SCOPE_REGEX: Regex = Regex::new(&format!(
-            "{}{}{}{}{}:",
-            *OPTIONAL_PRECEDING_WHITESPACE,
-            TYPE,
-            OPTIONAL_EXCLAMATION,
-            EMPTY_SCOPE,
-            OPTIONAL_EXCLAMATION
+            "{OPTIONAL_PRECEDING_WHITESPACE}{TYPE}{OPTIONAL_EXCLAMATION}{EMPTY_SCOPE}{OPTIONAL_EXCLAMATION}:",
         ))
         .unwrap();
     }
@@ -18,6 +13,3 @@ pub(crate) fn lint(commit_message: &str) -> Result<(), LintingError> {
         false => Ok(()),
     }
 }
-
-#[cfg(test)]
-mod tests;
