@@ -14,6 +14,3 @@ pub(crate) fn lint(commit_message: &str) -> Result<(), LintingError> {
         false => Ok(()),
     }
 }
-
-#[cfg(test)]
-mod tests;
